* migstat07_stata.zip: migstat07.do 
* =============================================================================

* Stata/MP 12.1 for Windows


clear
capture log close
set more off
* set memory 800m
set dp comma
set linesize 250

* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */ 
cd '<Arbeitsverzeichnis>'

log using migstat2007.log, replace text

/* ===========================================================================
Programmname: migstat07.do

STATA-PROGRAMM ZUR TYPISIERUNG DES MIGRATIONSSTATUS IM MIKROZENSUS 2007

Programmautor/en:
  SAS-Originalprogramm: Gunter Brueckner (Statistisches Bundesamt; 
     Referat F 204 Migration und integration, Wohnen)
  Anpassungen an Scientific Use File Mikrozensus 2007: Delia Jaeger,
     Bernhard Schimpl-Neimanns (GESIS, GML)

Programmzweck:
   Dieses Programm dient der Replikation des Migrationsstatus, Variable MIG, 
   und der Staatsangehoerigkeit zum Migrationsstatus (MIGS) im Scientific 
   Use File (SUF) des Mikrozensus 2007.
   Die Programme basieren auf den SAS-Programmen zum Original-Mikrozensus des
   Statistischen Bundesamtes und wurden an Recodierungen des SUF angepasst.
   Bei der Replikation der Variablen Staatsangehoerigkeit zum Migrationsstatus 
   (MIGS) ist zu beachten, dass aus Gruenden des Datenschutzes Angaben zur 
   zweiten Staatsangehoerigkeit (EF370) nur rudimentaer vorhanden sind. Des 
   Weiteren sind die zur Konstruktion von MIGS verwendeten Variablen
       EF369 1. Staatsangehoerigkeit 
   und EF374 Staatsangehoerigkeit: vor Einbuergerung/Zuzug als Spaetaussiedler
   unterschiedlich codiert. Die Replikation ist deshalb nur eingeschraenkt 
   moeglich.

Weiterfuehrende Programmbeschreibung: 
   Jaeger, Delia und Bernhard Schimpl-Neimanns: Typisierung des 
    Migrationshintergrundes in den Mikrozensus Scientific-Use-Files 2005-2009. 
    GESIS-Technical Report Nr. 2012/08. Mannheim: GESIS. URL: 
    http://www.gesis.org/fileadmin/upload/forschung/publikationen/gesis_reihen/
    gesis_methodenberichte/2012/TechnicalReport_2012-08.pdf.

Download dieser Datei:
   http://www.gesis.org/missy/studie/klassifikationen/konzepte-und-definitionen/
   migrationshintergrund/migstat07_stata.zip

Siehe auch Anhang 1: Personen mit Migrationshintergrund - Auf dem Weg zu einer 
   definitorischen Abgrenzung - S. 398-407 in: Statistisches Bundesamt, 2011: 
   Bevoelkerung mit Migrationshintergrund. Ergebnisse des Mikrozensus 2009. 
   Fachserie 1 Reihe 2.2. Wiesbaden. URL:
   https://www.destatis.de/DE/Publikationen/Thematisch/Bevoelkerung/
   MigrationIntegration/Migrationshintergrund2010220097004.pdf?__blob=
   publicationFile; letzter Zugriff: 24.07.2012.

Programmstruktur:
   0. Datenvorbereitung
   1. Grundtypisierung des Migationshintergrundes
   2. Identifikation von 3-Generationen-Haushalten
   3. Endtypisierung der Grosseltern
   4. Endtypisierung der Eltern
   5. Endtypisierung Befragte
   6. Umsetzung von Zeitreihenkompatibilitaet (entfaellt im MZ 2007)
   7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse

Programmstatus:
  Getestet mit Stata/MP 12.1 for Windows und dem Scientific Use File 
  Mikrozensus 2007, Version 1 vom 04. 12. 2009. Stand: Juli 2012
============================================================================ */

* Variablenauswahl Scientific Use File Mikrozensus 2007
*   Lokalen Dateinamen in <> eintragen
use EF1   EF3   EF4   EF5   EF8   EF9   EF12  EF30  EF31  EF44  ///
    EF46  EF47  EF49  EF50  EF51  EF52  EF53  EF54  EF55  EF366 ///
    EF367 EF368 EF369 EF370 EF371 EF372 EF373 EF374 EF663 EF952 ///
  using <mz2007.dta>, replace

* =====================================================================
* 0. Datenvorbereitung

 
/* DATENKORREKTUREN DOPPELTE IDs
   URL: http://www.gesis.org/download/fileadmin/missy/arbeitshilfen/mz2007/ID_2007.do
*/
do ID_2007.do

* Sichern Original-EF4 
rename EF4  EF4_ORG
rename EF4R EF4
label var EF4_ORG "SUF-Original Nr. des Haushalts im Auswahlbezirk (systemfrei) - vor Rekodierungen"
label var EF4     "Rekodierte Nr. des Haushalts im Auswahlbezirk (systemfrei)"

* Sichern Original-EF5 
rename EF5  EF5_ORG
rename EF5R EF5
label var EF5_ORG "SUF-Original Nr. der Person im Haushalt (systemfrei) - vor Rekodierungen"
label var EF5     "Rekodierte Nr. der Person im Haushalt (systemfrei)"

order EF4 EF5, before(EF12)
order ID_Org EF4_ORG EF5_ORG, after(EF952)

/* Datenkorrektur Mutter-Kind-Bezug
list EF3 EF4 EF5  EF52 EF53 EF44 EF46  if EF3==9931 & EF4==6, nolab noobs

  EF3   EFf4   EF5   EF52   EF53   EF44   EF46 
----------------------------------------------
 9931     6     1      1      2     44      2  ==> EF52=0 , EF53=99
 9931     6     2      1      1     14      2 
*/
gen EF52_ORG = EF52
gen EF53_ORG = EF53
replace EF52 =  0  if EF3==9931 & EF4==6 & EF5==1
replace EF53 = 99  if EF3==9931 & EF4==6 & EF5==1
order EF52_ORG EF53_ORG, after(EF5_ORG)


* Ausgangssortierung: Bundesland (EF1), Auswahlbezirk (EF3), Haushaltsnr. (EF4), Personennr. (EF5)
sort EF1 EF3 EF4 EF5

* Variablennamen Gross- => Kleinschreibung
renpfix EF ef

* Value Label um Code ergaenzen
numlabel _all, add mask("[#] ") force

* Speichern des Variablenauszugs SUF MZ 2007 mit korrigierten IDs
save mz2007r_mig.dta, replace


/* ============================================================================

HARMONISIERUNG DER STAATSANGEHOERIGKEITEN IM SCIENTIFIC USE FILE 

Im SUF sind die Staatsaengehoerigkeiten unterschiedlich codiert bzw. aus 
Datenschutzgruenden vergroebert. Zur 2. Staatsangeh. (EF370) ist nur bekannt,
ob diese vorhanden ist. In den Originaldaten sind die einzelnen 
Staatsangehoerigkeiten ausgewiesen.
Die Typisierung der Staatsangehoerigkeit zum Migrationsstatus des 
Statistischen Bundesamtes (SA_erw) kann deshalb nicht oder nur naeherungsweise
repliziert werden.
==> Harmonisierte Recodierung EF369 und EF374 .
==> Zuweisung oben "SA2=ef370;" deaktiviert, da EF370 = 1 vorhanden <> 1=Belgien */

rename ef369 ef369_Org 
rename ef374 ef374_Org

recode ef369_Org (59=58), gen(ef369) copyrest
label var ef369 "1. Staatsangehoerigkeit - recodiert"
format ef369 %2.0f

recode ef374_Org (8=4) (1=21) (3=25) (15 17=31) (30=33) (98=55), gen(ef374) copyrest
label var ef374 "Staatsangehoerigkeit: vor Einbuergerung/Zuzug als Spaetaussiedler - recodiert"
format ef374 %2.0f

/*
label def natio /// fuer EF369, EF374, SA_erw, MIGS
   0 "Entfaellt (Deutsche ohne weitere Staatsangehoerigkeit)" ///
   4 "4/8/27: Daenemark(4); Finnland(8); Schweden(27)" ///
   9 "Frankreich" ///
  10 "Griechenland" ///
  13 "Italien" ///
  21 "1/18/21: Belgien(1); Luxemburg(18); Niederlande(21)" ///
  22 "Oesterreich" ///
  23 "Polen" ///
  24 "Portugal" ///
  25 "3/25: Bulgarien(3); Rumaenien(25)" ///
  31 "7/15/17/19/31/37: Estland(7); Lettland(15); Litauen(17); Malta(19); Slowenien(31); Zypern(37)" ///
  32 "Spanien" ///
  33 "30/33: Slowakei(30); Tschechische Republik(33)" ///
  35 "Ungarn" ///
  36 "11/36: Irland(11); Vereinigtes Koenigreich(36)" ///
   2 "Bosnien und Herzegowina" ///
   5 "Ehemalige Sowjetunion" ///
   6 "Ehemaliges Jugoslawien" ///
  14 "Kroatien" ///
  26 "Russische Foederation" ///
  28 "12/16/20/28: Island(12); Liechtenstein(16); Norwegen(20); Schweiz(28)" ///
  34 "Tuerkei" ///
  38 "Sonstiges Osteuropa" ///
  39 "Sonstiges Europa" ///
  56 "Ukraine" ///
  58 "58/59: Serbien(58); Montenegro(59)" ///
  40 "Marokko" ///
  41 "Sonstiges Nordafrika" ///
  42 "Sonstiges Afrika (ohne Marokko)" ///
  43 "Vereinigte Staaten von Amerika (USA)" ///
  45 "44/45: Sonstiges Nordamerika [Kanada](44); Mittelamerika und Karibik(45)" ///
  46 "Suedamerika" ///
  47 "Irak" ///
  48 "Iran" ///
  49 "Sonstiger Naher und Mittlerer Osten (ohne Iran)" ///
  57 "Kasachstan" ///
  50 "Vietnam" ///
  51 "Afghanistan" ///
  52 "Sonstiges Sued- und Suedostasien" ///
  53 "China" ///
  54 "Sonstiges Ostasien" ///
  55 "55/98: Uebrige Welt(55); Staatenlos(98)" ///
  99 "Ohne Angabe bzw. unzutreffend"
*/

/* Zusammenfassungen
Europa: .
EU-27:               4  9 10 13 21 22 23 24 25 31 32 33 35 36
- Sonstiges Europa:  2  5  6 14 26 28 34 38 39 56 58  
Afrika:  40 41 42  
Amerika: 43 45 46  
Asien, Australien und Ozeanien 
- Naher und Mittlerer Osten: 47 48 49 57 
- Sued- und Suedostasien: 50 51 52 
- China, Sonstiges Ostasien: 53 54 
Uebrige Welt, Staatenlos: 55
============================================================================= */



/* ==========================================================================
  1. Grundtypisierung des Migrationshintergrundes 
  
     Es werden zunaechst nur die Angaben der Person selbst zur Typisierung 
     verwendet. Die erste Typisierung erfolgt nach Angaben zur 
     Staatsangehoerigkeit (deutsch / nicht-deutsch) und Geburtsland 
     (Ausland / Inland).                                  .
     Zur Unterscheidung der Gruppe eingebuergerter Zuwanderer (MIG=31) nach 
     einem evtl. Status als Spaetaussiedler wird abschliessend geprueft, ob 
     der Ehegatte, der Vater oder die Mutter im Haushalt einen 
     Spaetaussiedlerstatus besitzt.
     Trifft dies zu, erfolgt eine Rekodierung (Plausibilisierung) 
     von MIG=31 'zugewanderter eingebuergerter Auslaender'
     zu  MIG=22 'Ehegatte oder Kind eines (Spaet-)Aussiedlers 
     (mit/ohne Einbuerg)' */

generate gebj=ef47
label var gebj "Geburtsjahr (EF47)"

generate brdborn = ef366
label var brdborn "Geburtsland: BRD (EF366)"
label def brdborn 1 "Ja, hier geboren" 8 "Nein, zugezogen" 9 "ohne Angabe", add modify
label val brdborn brdborn

recode brdborn (1=0) (8=1) (9 .=9), gen(zuzug)
label var zuzug "Zuzug ex BRDBorn, EF366"
label def zuzug 0 "kein Zuzug" 1 "foreign born" 2 "Zuzug nach 6+ Mo im Ausland:= in D geboren" 9 "k.A.", add modify
label val zuzug zuzug

recode ef367 (1949=1949) (9999=9) (0=0), gen(jzuzug) copyrest
label def jzuzug 1949 "Zuzug vor 1950" 9 "o.A. zum Zuzugsjahr"  0 "kein Zuzugsjahr sinnvoll", add modify
label val jzuzug jzuzug

replace zuzug  = 2 if (brdborn==1 & jzuzug>9)
replace jzuzug = 9 if (brdborn==8 & jzuzug<10)

* Kontrolle
* tab1 brdborn zuzug jzuzug, miss


* Initialisierung
gen mig=.
gen ausl=.
gen sadopp=.
gen sa=.
gen sa1=.
gen sa2=.
gen sa3=.
gen spauss=.
gen eingeb=.
gen jeinb=.
gen sa_erw=.
format mig %2.0f ausl sadopp spauss eingeb %1.0f sa sa1 sa2 sa_erw %2.0f


* Staatsangehoerigkeit
* nur deutsche Staatsangehoerigkeit (SA)
replace ausl=0    if ef368==1
replace sadopp=0  if ef368==1
replace sa1=0     if ef368==1
replace sa2=.     if ef368==1
* deutsche und auslaendische SA 
replace ausl=0    if ef368==2
replace sadopp=1  if ef368==2
replace sa1=0     if ef368==2
replace sa2=ef369 if ef368==2
* nur auslaendische SAs 
replace ausl=1    if ef368==8 // ef368!=1 & ef368!=2
replace sa1=ef369 if ef368==8
replace sadopp=0  if ef368==8 & ef370==0 // ef370=0: Ausl. mit nur einer Staatsangeh.
replace sa2=.     if ef368==8 & ef370==0
replace sadopp=1  if ef368==8 & ef370!=0 
/* deaktiviert, weil EF370 keine Staatsangehoerigkeiten enthaelt ausser 1=ja: 
   replace sa2=ef370 if ef368==8 & ef370!=0
*/

label def ausl   0 "nein" 1 "ja"
label def sadopp 0 "nein" 1 "ja"
label val ausl ausl 

* Kontrolle
* tab1 ausl sadopp sa1 sa2, miss

/* ####### Eingebuergerte/Spaetaussiedler und Staatsangehoerigkeit davor ####### 
    Erwerb der dt. Staatsangehoerigkeit": (EF372 neue Codes ab 2007):
        Deutsche Staatsangehoerigkeit durch Geburt: Spaetaussiedler=9; Eingebuergert=0;
        Deutsche Staatsangehoerigkeit als Spaetaussiedler mit Einbuergerung: Spaetaussiedler=1; Eingebuergert=1;
        Deutsche Staatsangehoerigkeit als Spaetaussiedler ohne Einbuergerung: Spaetaussiedler=1; Eingebuergert=0;
        Deutsche Staatsangehoerigkeit durch Einbuergerung: Spaetaussiedler=0; Eingebuergert=1;
    JahrEinbuergerung (EF373): 1910-2006= jeweiliges Jahr; 9=k.A. 
    SA3: Staatsangehoerigkeit vor Einbuergerung/Zuzug als Spaetaussiedler (EF374): .=k.A.; 0=deutsch bzw. unzutreffend; 1-59,98=jeweilige auslaendische Staatsangehoerigkeit; 
*/

* Spaetaussiedler ohne Einbuergerung
replace spauss=1     if ef372==2
replace eingeb=0     if ef372==2
replace jeinb =.     if ef372==2
replace sa3 = ef374  if ef372==2
recode sa3 (0=.)     if ef372==2
replace sa2 = ef369  if ef372==2
recode sa2 (0=.)     if ef372==2
* Einbuergerung  
replace spauss=0     if ef372==3
replace eingeb=1     if ef372==3
replace jeinb =ef373 if ef372==3
recode jeinb (0=9)   if ef372==3
replace sa3 = ef374  if ef372==3
recode sa3 (0=.)     if ef372==3
replace sa2 = ef369  if ef372==3
recode sa2 (0=.)     if ef372==3
* Deutsch durch Geburt (EF372=0 Entfaellt, 1=Deutsche Staatsangehoerigkeit durch Geburt
replace spauss=0     if ef372<2
replace eingeb=0     if ef372<2
replace jeinb=.      if ef372<2
replace sa3=0        if ef372<2
replace sa2=ef369    if ef372<2
recode sa2 (0=.)     if ef372<2

label def spauss 0 "nein" 1 "ja"
label val spauss spauss
label def eingeb 0 "nein" 1 "ja"
label val eingeb eingeb

* KONTROLLE 1 
* tab1 sa1 sa2 sa3, miss


/*    ####### Grundtypisierung des Migrationshintergrundes ####### */
/*    MIG: Migrationstypus
    1. Stelle:     Migrationstyp: 
        1=vertrieben;
        2=als Deutsche/r bzw. Spaetaussiedler zugewandert;
        3=eingebuergert;
        4=Auslaender/in;
    2. Stelle:    Generation: 
        1=im Ausland geboren, 
        2=in Deutschland geboren 

    MIG:
        11=Vertriebene vor 1950;
        21=Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung);
        22=Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung);
        25=(Spaet-)Aussiedler (mit Einbuergerung);
        29=(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr;
        31=zugewanderte/r eingebuergerte/r Auslaender/in;
        32=nicht zugewanderte/r eingebuergerte/r Auslaender/in;
        41=zugewanderte/r Auslaender/in;
        42=nicht zugewanderte/r Auslaender/in;
        77=uneindeutig ob deutsch, vertrieben oder Spaetaussiedler 
        99=fehlende/unvollstaendige Angaben 
    SA: aktuelle Staatsangehoerigkeit

    SA_erw: erweiterte aktuelle Staatsangehoerigkeit
        gewonnen aus SA1 - SA3 nach folgenden Regeln:
        0=deutsch (bei MIG=0, 11);
        =SA1 (bei Mig=41,42);
        =SA3 (bei Mig=21,25,29,31,32 und SA3<>.);
        =SA2 (bei MIG=21,25,29,31,32 und SA3=.und SA2<>.)
        =99 (bei MIG=21,25,29,31,32 und SA2=. und SA3=. oder bei MIG=77,99)    */

* A)  im Ausland geboren 
* A1) als Auslaender zugewandert
replace mig=41      if brdborn==8 & ausl==1 & mig==.
replace sa=sa1      if brdborn==8 & ausl==1 & mig==41
replace sa_erw=sa1  if brdborn==8 & ausl==1 & mig==41

* A2) Spaetaussiedler/in
replace mig=25      if brdborn==8 & spauss==1 & eingeb==1 & mig==.
replace sa=sa1      if brdborn==8 & spauss==1 & eingeb==1 & mig==25
replace sa_erw=sa3  if brdborn==8 & spauss==1 & eingeb==1 & mig==25
replace sa_erw=sa2  if brdborn==8 & spauss==1 & eingeb==1 & mig==25 & sa_erw==.
replace sa_erw=99   if brdborn==8 & spauss==1 & eingeb==1 & mig==25 & sa_erw==.

* Spaetaussiedler ohne Einbuergerung XXX 2007 nicht differenzierbar XXX
replace mig=21      if brdborn==8 & spauss==1 & eingeb==0 & mig==.
replace sa=sa1      if brdborn==8 & spauss==1 & eingeb==0 & mig==21
replace sa_erw=sa3  if brdborn==8 & spauss==1 & eingeb==0 & mig==21
replace sa_erw=sa2  if brdborn==8 & spauss==1 & eingeb==0 & mig==21 & sa_erw==.
replace sa_erw=99   if brdborn==8 & spauss==1 & eingeb==0 & mig==21 & sa_erw==.

* kein Spaetaussiedler ...
* A3) Eingebuergerte/r
replace mig=31      if brdborn==8 & spauss==0 & eingeb==1 & mig==.
replace sa=sa1      if brdborn==8 & spauss==0 & eingeb==1 & mig==31
replace sa_erw=sa3  if brdborn==8 & spauss==0 & eingeb==1 & mig==31
replace sa_erw=sa2  if brdborn==8 & spauss==0 & eingeb==1 & mig==31 & sa_erw==.
replace sa_erw=99   if brdborn==8 & spauss==0 & eingeb==1 & mig==31 & sa_erw==.

* ... Deutsche/r durch Geburt
* A4) Vertriebener vor 1950
replace mig=11      if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==1949 & mig==.
replace sa=sa1      if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==1949 & mig==11
replace sa_erw=sa1  if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==1949 & mig==11

* A5) Aussiedler-Aequivalent
replace mig=21      if brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & mig==.
replace sa=sa1      if brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & mig==21
replace sa_erw=sa3  if brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & sa_erw==.
replace sa_erw=99   if brdborn==8 & spauss==0 & eingeb==0 & jzuzug>1949 & sa_erw==.

* ... Zuzugsjahr missing: Zuzug ohne Angabe zum Jahr d.h. kann Vertriebener
*     oder Spaetaussiedler sein
* Annahme 1: wenn nach 1949 geboren, als Spaetaussiedler zugewandert
replace mig=21      if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & mig==.
replace sa=sa1      if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & mig==21
replace sa_erw=sa3  if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & mig==21
replace sa_erw=sa2  if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & mig==21 & sa_erw==.
replace sa_erw=99   if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj>1949 & mig==21 & sa_erw==.

* Annahme 2: Wenn vor 1949 geboren und keine auslaendische SA dann Vertriebener
replace mig=11      if brdborn==8 & spauss==0 & eingeb==0 & gebj<=1949 & sadopp==0 & sa1==0 & mig==.
replace sa=sa1      if brdborn==8 & spauss==0 & eingeb==0 & gebj<=1949 & sadopp==0 & sa1==0 & mig==11
replace sa_erw=sa1  if brdborn==8 & spauss==0 & eingeb==0 & gebj<=1949 & sadopp==0 & sa1==0 & mig==11

* Annahme 3: sonst Zuzug als Spaetaussiedler ohne Datumsangabe: 29 
replace mig=29      if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & mig==.
replace sa=sa1      if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & mig==29
replace sa_erw=sa3  if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & mig==29
replace sa_erw=sa2  if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & mig==29 & sa_erw==.
replace sa_erw=99   if brdborn==8 & spauss==0 & eingeb==0 & jzuzug==9 & gebj<=1949 & sadopp==1 & sa1==0 & mig==29 & sa_erw==.

* B)  im Inland geboren
* B1) als Auslaender in D geboren
replace mig=42      if brdborn==1 & ausl==1 & mig==.
replace sa=sa1      if brdborn==1 & ausl==1 & mig==42
replace sa_erw=sa1  if brdborn==1 & ausl==1 & mig==42

* B2) Spaetaussiedler/in, Fehler! .
replace mig=77      if brdborn==1 & spauss==1 & mig==.
replace sa=sa1      if brdborn==1 & spauss==1 & mig==77
replace sa_erw=sa3  if brdborn==1 & spauss==1 & mig==77
replace sa_erw=sa2  if brdborn==1 & spauss==1 & mig==77 & sa_erw==.
replace sa_erw=99   if brdborn==1 & spauss==1 & mig==77 & sa_erw==.

* B3) Eingebuergerte/r 
replace mig=32      if brdborn==1 & eingeb==1 & mig==.
replace sa=sa1      if brdborn==1 & eingeb==1 & mig==32
replace sa_erw=sa3  if brdborn==1 & eingeb==1 & mig==32
replace sa_erw=sa2  if brdborn==1 & eingeb==1 & mig==32 & sa_erw==.
replace sa_erw=99   if brdborn==1 & eingeb==1 & mig==32 & sa_erw==.

* B4) in Deutschland geborener Deutscher 
replace mig=77      if brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & mig==.
replace sa=sa1      if brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & mig==77
replace sa_erw=sa2  if brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & mig==77
replace sa_erw=sa1  if brdborn==1 & ausl==0 & spauss==0 & eingeb==0 & mig==77 & sa_erw==.

* keine Auskunft; kommt wohl nicht vor
replace mig=99      if brdborn==9 & mig==.
replace sa=sa1      if brdborn==9 & mig==99
replace sa_erw=sa3  if brdborn==9 & mig==99
replace sa_erw=sa1  if brdborn==9 & mig==99 & sa_erw==.

rename mig mig1
label var mig1 "Migrationsstatus Grundtypisierung vor Plausibilisierung Spaetaussiedler (MIG=31)"


* KONTROLLE 2
* tab1 mig sa_erw, miss


/* =============================================================================
Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31), dann pruefen, ob ggf. 
Spaetaussiedlerstatus vorliegt:
 a) Ehegatte ist Spaetaussiedler (MIG[Ehegatte]=21-29)
 b) Vater ist Spaetaussiedler (MIG[Vater]=21-29)
 c) Mutter ist Spaetaussiedler (MIG[Mutter]=21-29) 
*/

* A) PLAUSIBILISIERUNG - EHEGATTE 

*  Valide Spaetaussiedler 
gen vorl = (ef366==8 & ef372==2 & jzuzug>1949)
label var vorl "Valide Spaetaussiedler - PERSON"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

* EHEGATTEN IM HAUSHALT
preserve
keep if ef50==1  // Ehegatte im Haushalt
keep  ef1 ef3 ef4 ef5 ef50 mig1 vorl jzuzug ef366 ef372 
rename ef5    ef5_e
rename jzuzug jzuzug_e
rename ef366  ef366_e
rename ef372  ef372_e
rename mig1   mig1_e
rename vorl   vorl_e
sort ef1 ef3 ef4 ef5_e ef50
save temp_e.dta, replace
restore 

* GESAMTFILE 
use temp.dta, clear
gen ef5_e = ef51 * (ef50==1)
label var ef5_e "Nr. des Ehepartners im Haushalt (EF51)"
* Sortierung fuer Zusammenspielen Ehegatten
sort ef1 ef3 ef4 ef5_e

* Angaben der Ehegatten zusammenspielen 
merge m:m ef1 ef3 ef4 ef5_e ef50 using temp_e.dta
* tab _merge ef50, miss 
drop _merge

* Sortierung des Ausgangsfiles wieder herstellen: 
sort ef1 ef3 ef4 ef5

gen mig1a = mig1
label var mig1a "Migrationsstatus nach Plausib a) Ehegatte"
replace mig1a=22 if (mig1==31    /// Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31) 
                   & jzuzug>10   /// und valides Zuzugsjahr 
                   & ef50==1     /// Ehegatte im Haushalt (ergaenzt) 
                   & (abs(jzuzug-jzuzug_e)<3) /// Diff +- 3 Jahre zum Zuzugsjahr des Ehegatten 
                   & vorl_e==1)               //  Ehegatte ist valider Spaetaussiedler:= ef366 = 8 & (ef372=2 | ef372=4) & JZuzug>1949 
* n=126 Rekodierungen 31 -> 22

* ----------------------------------------------------------------------------

* B) PLAUSIBILISIERUNG - VATER .
*    EF54 Vater im Haushalt: fuer Ledige: 1=ja 8=nein 0=entf.
*    EF55 Nr. des Vaters im Haushalt .

gen vnr = ef55 if (ef54==1)
label var vnr "Personennr. des Vaters (EF55)"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

preserve
keep if ef54==1
keep ef1 ef3 ef4 vnr

* ==> Sortierung ... vnr
sort ef1 ef3 ef4 vnr
rename vnr ef5
gen v_kids=1
collapse (count) v_kids, by(ef1 ef3 ef4 ef5)
label var v_kids "Anzahl lediger Kinder eines Vaters"
save temp_v1.dta, replace
restore


* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 ef4 ef5

* Anzahl der Kinder den Vaetern zuspielen 
merge m:m ef1 ef3 ef4 ef5 using temp_v1.dta
* tab _merge, miss
drop _merge

recode v_kids (1/99=1), gen(vater)
label var vater "Vater lediger Kinder im HH"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

preserve
keep if (vater==1)
keep  ef1 ef3 ef4 ef5 mig1a vorl jzuzug ef366 ef372 
rename ef5     vnr
rename jzuzug jzuzug_v
rename ef366  ef366_v
rename ef372  ef372_v
rename mig1a  mig_v
rename vorl   vorl_v
sort ef1 ef3 ef4 vnr
save temp_v1.dta, replace
restore

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 ef4 vnr
* Angaben des Vaters zuspielen 
merge m:m ef1 ef3 ef4 vnr using temp_v1.dta
* tab _merge ef54, miss
drop _merge
* tab mig_v vater

* Sortierung des Ausgangsfiles wieder herstellen
sort ef1 ef3 ef4 ef5

gen mig1b = mig1a
label var mig1b "Migrationsstatus nach Plausib a) Eheg. + b) Vater"

replace mig1b=22 if (mig1a==31      /// Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31)
                    & jzuzug>10     /// und valides Zuzugsjahr
                    & ef54==1       /// Vater im Haushalt (ergaenzt)
                    & (abs(jzuzug-jzuzug_v)<3)  /// Diff +- 3 Jahre zum Zuzugsjahr des Vaters
                    & vorl_v==1)    //  Vater ist valider Spaetaussiedler:= ef366 = 8 & (ef372=2 | ef372=4) & JZuzug>1949
* n=29 Rekodierungen 31 -> 22

* ----------------------------------------------------------------------------
* C) PLAUSIBILISIERUNG - MUTTER 
*    EF52 Mutter im Haushalt: fuer Ledige: 1=ja 8=nein 0=entf
*    EF53 Nr. der Mutter im Haushalt 
gen mnr = ef53 if (ef52==1)
label var mnr "Personennr. der Mutter (EF53)"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

preserve
keep if ef52==1
keep ef1 ef3 ef4 mnr

* ==> Sortierung ... mnr
sort ef1 ef3 ef4 mnr
rename mnr ef5
gen m_kids=1
collapse (count) m_kids, by(ef1 ef3 ef4 ef5)
label var m_kids "Anzahl lediger Kinder einer Mutter"
save temp_m1.dta, replace
restore

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 ef4 ef5

* Anzahl der Kinder den Muettern zuspielen 
merge m:m ef1 ef3 ef4 ef5 using temp_m1.dta
tab _merge ef52, miss
drop _merge

recode m_kids (1/99=1), gen(mutter)
label var mutter "Mutter lediger Kinder im HH"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

preserve
keep if (mutter==1)
keep  ef1 ef3 ef4 ef5 mig1b vorl jzuzug ef366 ef372 
rename ef5    mnr
rename jzuzug jzuzug_m
rename ef366  ef366_m
rename ef372  ef372_m
rename mig1b  mig_m
rename vorl   vorl_m
sort ef1 ef3 ef4 mnr
save temp_m1.dta, replace
restore


* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 ef4 mnr
* Angaben der Mutter zuspielen 
merge m:m ef1 ef3 ef4 mnr using temp_m1.dta
* tab _merge ef52, miss
drop _merge
* tab mig_m mutter

* Sortierung des Ausgangsfiles wieder herstellen
sort ef1 ef3 ef4 ef5

gen mig1c = mig1b
label var mig1c "Migrationsstatus nach Plausib a) Eheg. + b) Vater + c) Mutter"

replace mig1c=22 if (mig1b==31      /// Wenn Zuwanderer angibt, eingebuergert zu sein (Mig=31)
                 & jzuzug>10        /// und valides Zuzugsjahr
                 & ef52==1          /// Mutter im Haushalt (ergaenzt)
                 & (abs(jzuzug-jzuzug_m)<3)  /// Diff +- 3 Jahre zum Zuzugsjahr der Mutter
                 & vorl_m==1)       //  Mutter ist valider Spaetaussiedler:= EF366 = 8 & (EF372=2 | EF372=4) & JZuzug>1949
* n=8 Rekodierungen 31 -> 22

gen mig2 = mig1c
label var mig2 "Migrationsstatus Grundtypisierung nach Plausibilisierungen (MIG=31, a-c)"

* Kontrolle 3
* tab1 mig2 sa_erw, miss


/* ====================================================================
   2. Identifikation von 3-Generationen-Haushalten

      Fuer die nachfolgende Typisierung des Migrationshintergrundes 
      von Eltern unter Verwendung von Angaben der Grosseltern werden
      in diesem Schritt 3-Generationen-Haushalte identifiziert und
      Identifikatoren fuer Grossmuetter- und -vaeter gebildet. 
 */

sort ef1 ef3 ef4 ef5

* Eltern (Mutter oder Vater) mit Angaben zur (Gross-)Mutter: Personennummer der Grossmutter
generate gmnr = ( (mutter==1 | vater==1) & ef52==1) * ef53

* Eltern (Mutter oder Vater) mit Angaben zum (Gross-)Vater: Personennummer des Grossvaters
generate gvnr = ( (mutter==1 | vater==1) & ef54==1) * ef55

egen min_gmnr = min(gmnr * (gmnr>0)), by(ef1 ef3 ef4)
egen max_gmnr = max(gmnr * (gmnr>0)), by(ef1 ef3 ef4)
egen min_gvnr = min(gvnr * (gvnr>0)), by(ef1 ef3 ef4)
egen max_gvnr = max(gvnr * (gvnr>0)), by(ef1 ef3 ef4)

* Kontrolle: mehr als 1 Grossmutter(nummer) im HH?
tab max_gmnr min_gmnr if max_gmnr!=min_gmnr & (min_gmnr>0)

* Kontrolle: mehr als 1 Grossvater(nummer) im HH?
tab max_gvnr min_gvnr if max_gvnr!=min_gvnr & (min_gvnr>0)

* Grossvater-/mutter [Voraussetzung fuer Verwendung von "max": 1 GM, 1 GV]
gen gmutter = (max_gmnr==ef5) if max_gmnr>0
gen gvater  = (max_gvnr==ef5) if max_gvnr>0


* ZWISCHENSPEICHERUNG GESAMTFILE VOR ENDTYPISIERUNG ELTERN
*    Ausgangssortierung
sort ef1 ef3 ef4 ef5
save temp.dta, replace

/* ====================================================================
   3. Endtypisierung der Grosseltern .
      Im MZ 2007 nicht relevant, da keine Angaben zu den nicht im HH lebenden
      Eltern vorhanden, deshalb kann die Grundtypisierung verwendet werden. */


/* ====================================================================
   4. Endtypisierung der Eltern 
      Fuer jede Kombination von eigenem, vaeterlichen und 
      muetterlichen vorlaeufigen Migrationsstatus wird der 
      resultierende endgueltige Migrationsstatus zugewiesen. Diese 
      Konversions-Prozedur wird nur fuer im Inland Geborene angewandt.
      Abschliessend wird die Variable erweiterte Staatsangehoerigkeit
      (SA_erw) ggf. durch Informationen zum Vater bzw. zur Mutter 
      ergaenzt. 
(...)
conversion.dta --- ex conversion_2011.xls ---
n=1193 Zeilen
 Inhalt: _mig_   Migrationsstatus Befragter VOR Konversion
         _migv_  Migrationsstatus Vater
         _migm_  Migrationsstatus Mutter
         migneu  Migrationsstatus Befragter konvertiert
 jeweils min=0, max=99
 sortiert nach:  _mig_  _migv_  _migm_

'Converse' enthaelt die Abbildungsvorschriften zur Ermittlung des 
Migrationsstatus aus den Werten MIG, MIGV und MIGM. 
Fuer jede Kombination von eigenem, vaeterlichen und muetterlichen 
vorlaeufigen Migrationsstatus wird der resultierende endgueltige
Migrationsstatus zurueckgegeben. Die Variable Kennung enthaelt den 
Fallidentifikator, der die Abbildungsvorschrift eindeutig identifiziert 
(...)
Nur im Inland Geborene werden der Konversions-Prozedur unterworfen 
Durch Konversion koennen fuer Vater und Mutter neue Mig-Werte entstanden sein,
fuer die die Konversionstabelle keine Abbildungvorschrift enthaelt. Fuer diese Werte
werden kompatible, in der Konversionstabelle definierte Ersatzwerte eingestellt 
*/

* Migrationsrelevante Eintraege der Grossvaeter
egen mig_gv    = max(mig2*(gvater==1)), by(ef1 ef3 ef4)
egen sa1_gv    = max(sa1*(gvater==1)), by(ef1 ef3 ef4)
egen sa2_gv    = max(sa2*(gvater==1)), by(ef1 ef3 ef4)
egen sa3_gv    = max(sa3*(gvater==1)), by(ef1 ef3 ef4)
egen sa_gv     = max(sa*(gvater==1)),  by(ef1 ef3 ef4)
egen sa_erw_gv = max(sa_erw*(gvater==1)), by(ef1 ef3 ef4)
recode mig_gv sa1_gv sa2_gv sa3_gv sa_gv sa_erw_gv (nonmiss=.) if gvnr!=ef55

* Migrationsrelevante Eintraege der Grossmuetter
egen mig_gm    = max(mig2*(gmutter==1)), by(ef1 ef3 ef4)
egen sa1_gm    = max(sa1*(gmutter==1)), by(ef1 ef3 ef4)
egen sa2_gm    = max(sa2*(gmutter==1)), by(ef1 ef3 ef4)
egen sa3_gm    = max(sa3*(gmutter==1)), by(ef1 ef3 ef4)
egen sa_gm     = max(sa*(gmutter==1)),  by(ef1 ef3 ef4)
egen sa_erw_gm = max(sa_erw*(gmutter==1)), by(ef1 ef3 ef4)
recode mig_gm sa1_gm sa2_gm sa3_gm sa_gm sa_erw_gm (nonmiss=.) if gmnr!=ef53

recode mig2 (11 21 22 23 25 29 31 41=.) (*=1), gen(konvproc)

* Eltern-Grosseltern
gen egre = 1 if ( (mutter==1 & gmnr==ef53) |   /// Muetter mit Grossmuettern im HH 
                  (vater==1  & gvnr==ef55) )   //  Vaeter  mit Grossvaetern im HH 

generate _mig_  = mig2     if (egre==1 & konvproc==1) // MIG-Status Person, hier: Eltern
generate _migv_ = mig_gv   if (egre==1 & konvproc==1) // MIG-Status Grossvater
generate _migm_ = mig_gm   if (egre==1 & konvproc==1) // MIG-Status Grossmutter
recode   _mig_  (0=99)  if (egre==1 & konvproc==1) 
recode   _migv_ (0=99)  if (egre==1 & konvproc==1) 
recode   _migm_ (0=99)  if (egre==1 & konvproc==1) 
replace  _migm_ = 99 if (konvproc==1 & (vater==1 | mutter==1) & _migm_==.)
replace  _migv_ = 99 if (konvproc==1 & (vater==1 | mutter==1) & _migv_==.)


* Konversionstabelle zuspielen 
merge m:1 _mig_ _migv_ _migm_  using conversion.dta, keep(master matched)
tab _merge, miss
drop _merge

drop konvproc
recode mig2 (11 21 22 23 25 29 31 41=.) (*=1), gen(konvproc)

* Uebernahme konvertierter MIG-Typisierung
gen mig3 = mig2
replace mig3 = migneu if (egre==1 & konvproc==1 & migneu!=.)
label var mig3 "Migrationsstatus nach Endtypisierung Eltern"
format mig3 %2.0f

* SA_erw durch aussagekraeftigen Vater- oder Muttereintrag ergaenzen, 
* sofern noetig und moeglich 
*      if ((SA_erw in (0,99)) and (SA_erwV not in (0,99))) then SA_erw=SA_erwV; .
replace sa_erw = sa_erw_gv if (konvproc==1 & egre==1 & ( (sa_erw==0 | sa_erw==99) & (sa_erw_gv>0 & sa_erw_gv<99) ) )
replace sa_erw = sa_erw_gm if (konvproc==1 & egre==1 & ( (sa_erw==0 | sa_erw==99) & (sa_erw_gm>0 & sa_erw_gm<99) ) )

* Konversionsangaben loeschen
drop  _mig_ _migv_ _migm_ migneu kennung konvproc


* ZWISCHENSPEICHERUNG GESAMTFILE NACH ENDTYPISIERUNG ELTERN
*    Ausgangssortierung
sort ef1 ef3 ef4 ef5
save temp.dta, replace

* KONTROLLE 4
* tab1 mig3 sa_erw, miss


/* ====================================================================
   5. Endtypisierung Befragte
      Analog zur Endtypisierung der Eltern wird der endgueltige
      Migrationsstatus unter Beruecksichtigung der Kombinationen
      von eigenem, vaeterlichen und muetterlichen vorlaeufigen
      Migrationsstatus zugewiesen, wobei auch hier die Zuweisunge
      nur fuer die im Inland Geborenen zur Anwendung kommen, und
      die erweiterte Staatsangehoerigkeit (SA_erw) ggf. durch
      Angaben des Vaters bzw. der Mutter ergaenzt wird.
      Die Variable SA_erw ist Basis der Staatsangehoerigkeit zum 
      Migrationsstatus (MIGS). */

drop mig_v  jzuzug_v // alte Vater-Angaben
drop mig_m  jzuzug_m // alte Mutter-Angaben


* Migrationsrelevante Eintraege fuer Vaeter:  MIG  SA1 SA2 SA3 SA SA_erw JZuzug.

preserve
keep if vater==1
keep ef1 ef3 ef4 ef5   mig3  sa1   sa2    sa3    sa    sa_erw    jzuzug
rename ef5     vnr 
rename mig3    mig_v
rename sa1     sa1_v
rename sa2     sa2_v
rename sa3     sa3_v
rename sa_erw  sa_erw_v
rename jzuzug  jzuzug_v
sort ef1 ef3 ef4 vnr
save temp_v.dta, replace
restore

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 ef4 vnr
* Angaben des Vaters zuspielen 
merge m:m ef1 ef3 ef4 vnr using temp_v.dta
* tab _merge ef54
drop _merge
* tab mig_v vater

* Ausgangssortierung
sort ef1 ef3 ef4 ef5

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

preserve
keep if mutter==1
keep ef1 ef3 ef4 ef5   mig3  sa1   sa2    sa3    sa    sa_erw    jzuzug
rename ef5     mnr 
rename mig3    mig_m
rename sa1     sa1_m
rename sa2     sa2_m
rename sa3     sa3_m
rename sa_erw  sa_erw_m
rename jzuzug  jzuzug_m
sort ef1 ef3 ef4 mnr
save temp_m.dta, replace
restore

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 ef4 mnr
* Angaben der Mutter zuspielen 
merge m:m ef1 ef3 ef4 mnr using temp_m.dta
* tab _merge ef52
drop _merge
* tab mig_m mutter

* Zwischenspeicherung Gesamtfile
sort ef1 ef3 ef4 ef5
save temp.dta, replace


* nur im Inland Geborene werden der Konversions-Prozedur unterworfen 
recode mig3 (11 21 22 23 25 29 31 41=.) (*=1), gen(konvproc)

* Vorbereitung MATCH Konversionstabelle
generate _mig_  = mig3  if konvproc==1      // MIG-Status Person
generate _migv_ = mig_v if konvproc==1      // MIG-Status Vater
generate _migm_ = mig_m if konvproc==1      // MIG-Status Mutter
recode   _migv_ (.=99) (22 23=21) if konvproc==1
recode   _migm_ (.=99) (22 23=21) if konvproc==1

* ZWISCHENSPEICHERUNG GESAMTFILE
*    Ausgangssortierung
sort ef1 ef3 ef4 ef5
save temp.dta, replace

merge m:1 _mig_ _migv_ _migm_  using conversion.dta, keep(master matched)
* tab _merge, miss
drop _merge

drop konvproc // relevante Rekodierung ggf durch merge ueberschrieben
recode mig3 (11 21 22 23 25 29 31 41=.) (*=1), gen(konvproc)

generate mig4 = mig3
replace  mig4 = migneu if konvproc==1 & migneu!=.
label var mig4 "Migrationsstatus nach Endtypisierung Befragte"
format mig4 %2.0f

gen sa_erw0=sa_erw
* SA_erw durch aussagekraeftigen Vater- und Muttereintrag ergaenzen, sofern noetig und moeglich 
replace sa_erw = sa_erw_v if (konvproc==1 & (sa_erw==0 | sa_erw==99) & (sa_erw_v>0 & sa_erw_v<99) )
replace sa_erw = sa_erw_m if (konvproc==1 & (sa_erw==0 | sa_erw==99) & (sa_erw_m>0 & sa_erw_m<99) )


* Konversionsangaben loeschen
drop migneu  _mig_  _migv_  _migm_ kennung konvproc      /*_merge und kennung geloescht*/

* Ausgangssortierung
sort ef1 ef3 ef4 ef5


* 6. Umsetzung von Zeitreihenkompatibilitaet entfaellt im MZ 2007 



/* ====================================================================
  7. Variablendefinitionen wie im SUF und fuer Fachserien-Ergebnisse  

     Recodierungen wie SUF MZ 2008, 2009 */
recode mig4 (29=21) (77=0), gen(mig)
label var mig "Migrationsstatus"
format mig %2.0f
label def mig /// Kurzlabel
  0 "Deutsch ohne Migrationshintergrund" ///
 11 "Zuwanderer: bis einschl. 1949 als Deutscher ohne Einbuergerung zugewandert" ///
 21 "Zuwanderer: >=1950 als Deutscher ohne Einbuerg. zugew.; 2007: Spaetaussiedler" ///
 22 "2007: Ehegatte o. Kind v. Spaetaussiedler, zeitgleich eingereist" ///
 25 "2008: Spaetaussiedler mit formaler Einbuergerung" ///
 29 "Zuwanderer: o.A. Zuzugsjahr als Deutscher ohne Einbuerg. zugewandert" ///
 31 "Zuwanderer: als Auslaender zugewandert und zwischenzeitl. eingebuergert" ///
 32 "Hier geboren: als Auslaender in D geboren und zwischenzeitl. eingebuergert" ///
 41 "Zuwanderer: als Auslaender zugewandert" ///
 42 "Hier geb.: als Ausl. in D geboren, beide Eltern o. 1 Elternteil als Ausl. zugew., anderer E-Teil als Ausl. in D geboren" ///
 43 "Hier geb.: als Ausl. in D geboren, beide Eltern in D geboren" /// 
 52 "Hier geb.: Deutscher 1seit. Mig-hintergr.; mit Eltern im HH lebend; 1 Elternteil Spaetaussiedler (21-29)" ///
 53 "Hier geb.: Deutscher 1seit. Mig-hintergr.; mit Eltern im HH lebend; 1 Elternteil Deutscher durch Einbuerg. (31,32)" ///
 54 "Hier geb.: Deutscher 1seit. Mig-hintergr.; mit Eltern im HH lebend; 1 Elternteil Auslaender (41-43)" ///
 57 "Hier geb.: Deutscher 2seit. Mig-hintergr.; teilw. 1seit. Mig-hintergr., nur mit 1 Elternteil im HH; Elternteil Spaetaussiedler (21-29) [2005 und 2009]" ///
 58 "Hier geb.: Deutscher 2seit. Mig-hintergr.; teilw. 1seit. Mig-hintergr., nur mit 1 Elternteil im HH; Elternteil eingebuergert (31,32) [2005 und 2009]" /// 
 59 "Hier geb.: Deutscher 2seit. Mig-hintergr.; teilw. 1seit. Mig-hintergr., nur mit 1 Elternteil im HH; Elternteil Auslaender (41-43) [2005 und 2009]" ///
 62 "Hier geb.: Deutscher 2seit. Mig-hintergr.; mit Eltern im HH; mind. 1 Elternteil Spaetaussiedler (21-29)" ///
 63 "Hier geb.: Deutscher 2seit. Mig-hintergr.; mit Eltern im HH; beide Eltern eingebuergert, (31,32) oder 1 Elternteil eingeb. (31,32), anderer Auslaender (41-43)" ///
 64 "Hier geb.: Deutscher 2seit. Mig-hintergr.; mit Eltern im HH; beide Eltern Auslaender (41-43), ius soli-Kind (Optionsmodell)" ///
 72 "Hier geb.: Deutscher 1seit. Mig-hintergr.; nicht mit jenem Elternteil im HH, der als Spaetaussiedler (21-29) fuer Mig-hintergr. bestimmend [2005]" ///
 73 "Hier geb.: Deutscher 1seit. Mig-hintergr.; nicht mit jenem Elternteil im HH, der als Deutscher d. Einbuerg. (31,32) bestimmend [2005]" ///
 74 "Hier geb.: Deutscher 1seit. Mig-hintergr.; nicht mit jenem Elternteil im HH, der als Auslaender (41-43) bestimmend [2005]" ///
 77 "Hier geb.: Deutscher 2seit. Mig-hintergr.; mit keinem Elternteil im HH; mind. 1 Elternteil Spaetaussiedler (21-29) [2005 und 2009] {nicht mit Konversion zugeordnete Werte}" ///
 78 "Hier geb.: Deutscher 2seit. Mig-hintergr.; mit keinem Elternteil im HH; beide Eltern eingeb., (31,32) oder 1 Elternteil eingeb. (31,32), anderer Auslaender (41-43) [2005 und 2009]" /// 
 79 "Hier geb.: Deutscher 2seit. Mig-hintergr.; mit keinem Elternteil im HH; beide Eltern Auslaender (41-43), ius soli-Kind (Optionsmodell) [2005 und 2009]"
label val mig mig
numlabel mig, add mask("[#] ") force

/* 
label def mig /// Vollstaendige Value Labels
  0 "Deutsch ohne Migrationshintergrund" ///
 11 "Zuwanderer: bis einschliesslich 1949 als Deutscher ohne Einbuergerung auf das heutige Bundesgebiet zugewandert" ///
 21 "Zuwanderer: 1950 und spaeter als Deutscher ohne Einbuergerung auf das heutige Bundesgebiet zugewandert; 2007: Spaetaussiedler" ///
 22 "2007: Ehegatte oder Kind von Spaetaussiedler, zeitgleich eingereist (zaehlt ab 2008 zur Zahl der Eingebuergerten insgesamt) ///
 25 "2008: Spaetaussiedler mit formaler Einbuergerung (zaehlt ab 2008 zur Zahl der Eingebuergerten insgesamt)" ///
 29 "Zuwanderer: ohne Angabe des Zuzugsjahrs als Deutscher ohne Einbuergerung auf das heutige Bundesgebiet zugewandert" ///
 31 "Zuwanderer: als Auslaender auf das heutige Bundesgebiet zugewandert und zwischenzeitlich eingebuergert" ///
 32 "Hier geboren: als Auslaender im heutigen Bundesgebiet geboren und zwischenzeitlich eingebuergert" ///
 41 "Zuwanderer: als Auslaender auf das heutige Bundesgebiet zugewandert" ///
 42 "Hier geboren: als Auslaender im heutigen Bundesgebiet geboren, entweder beide Eltern als Auslaender zugewandert oder der eine Elternteil als Auslaender zugewandert, der andere als Auslaender im heutigen Bundesgebiet geboren" ///
 43 "Hier geboren: als Auslaender im heutigen Bundesgebiet geboren, beide Eltern im heutigen Bundesgebiet geboren" /// 
 52 "Hier geboren: Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt lebend; ein Elternteil ist Spaetaussiedler (21, 22, 25, 29)" ///
 53 "Hier geboren: Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt lebend; ein Elternteil ist Deutscher durch Einbuergerung (31, 32)" ///
 54 "Hier geboren: Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt lebend; ein Elternteil ist Auslaender (41, 42, 43)" ///
 57 "Hier geboren: Deutscher mit beidseitigem Migrationshintergrund; der beidseitige Migrationshintergrund ist nicht durchweg identifizierbar, sondern erscheint teilweise als einseitiger Migrationshintergrund, weil der Betroffenen nur mit einem Elternteil im Haushalt lebt; dieser Elternteil ist Spaetaussiedler (21, 22, 25, 29) [tritt nur in 2005 und 2009 auf]" ///
 58 "Hier geboren: Deutscher mit beidseitigem Migrationshintergrund; der beidseitige Migrationshintergrund ist nicht durchweg identifizierbar, sondern erscheint teilweise als einseitiger Migrationshintergrund, weil der Betroffenen nur mit einem Elternteil im Haushalt lebt; dieser Elternteil ist eingebuergert (31, 32) [tritt nur in 2005 und 2009 auf]" /// 
 59 "Hier geboren: Deutscher mit beidseitigem Migrationshintergrund; der beidseitige Migrationshintergrund ist nicht durchweg identifizierbar, sondern erscheint teilweise als einseitiger Migrationshintergrund, weil der Betroffenen nur mit einem Elternteil im Haushalt lebt; dieser Elternteil ist Auslaender (41, 42, 43) [tritt nur in 2005 und 2009 auf]" ///
 62 "Hier geboren: Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt lebend; mindestens ein Elternteil ist Spaetaussiedler (21, 22, 25, 29)" ///
 63 "Hier geboren: Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt lebend; entweder beide Eltern eingebuergert, (31, 32) oder ein Elternteil eingebuergert (31, 32), der andere Auslaender (41, 42, 43)" ///
 64 "Hier geboren: Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus durchweg identifizierbar, weil mit Eltern im Haushalt lebend; beide Eltern sind Auslaender (41, 42, 43), es handelt sich um ein ius soli-Kind (Optionsmodell)" ///
 72 "Hier geboren: Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus nicht durchweg identifizierbar, weil nicht mit jenem Elternteil im Haushalt lebend, der als Spaetaussiedler (21, 22, 25, 29) fuer den Migrationshintergrund bestimmend ist [tritt nur in 2005 auf]" ///
 73 "Hier geboren: Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus nicht durchweg identifizierbar, weil nicht mit jenem Elternteil im Haushalt lebend, der als Deutscher durch Einbuergerung (31, 32) fuer den Migrationshintergrund bestimmend ist [tritt nur in 2005 auf]" ///
 74 "Hier geboren: Deutscher mit einseitigem Migrationshintergrund; Migrationsstatus nicht durchweg identifizierbar, weil nicht mit jenem Elternteil im Haushalt lebend, der als Auslaender (41, 42, 43) fuer den Migrationshintergrund bestimmend ist [tritt nur in 2005 auf]" ///
 77 "Hier geboren: Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus nicht durchweg identifizierbar, weil mit keinem Elternteil im Haushalt lebend; mindestens ein Elternteil ist Spaetaussiedler (21, 22, 25, 29) [tritt nur in 2005 und 2009 auf] {nicht mit Konversion zugeordnete Werte}" ///
 78 "Hier geboren: Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus nicht durchweg identifizierbar, weil mit keinem Elternteil im Haushalt lebend; entweder beide Eltern eingebuergert, (31, 32) oder ein Elternteil eingebuergert (31, 32), der andere Auslaender (41, 42, 43) [tritt nur in 2005 und 2009 auf]" /// 
 79 "Hier geboren: Deutscher mit beidseitigem Migrationshintergrund; Migrationsstatus nicht durchweg identifizierbar, weil mit keinem Elternteil im Haushalt lebend; beide Eltern sind Auslaender (41, 42, 43), es handelt sich um ein ius soli-Kind (Optionsmodell) [tritt nur in 2005 und 2009 auf]"
*/



* MIGS Erweiterte Staatsangehoerigkeit zum Migrationsstatus (MIG)
*         fuer einheimische Bevoelkerung auf Null setzen 
* ZU BEACHTEN: Eingeschraenkte Vergleichbarkeit mit Veroeffentlichungen
* der statistischen Aemter aufgrund vergroeberter Angaben zur Staatsangehoerigkeit
* und fehlenden Angaben zur 2. Staatsangehoerigkeit im Scientific Use File
gen migs = sa_erw
replace migs = 0 if mig==0 | mig==11
label var migs "Erweiterte Staatsangehoerigkeit zum Migrationsstatus (MIG)"
format migs %2.0f
label def migs  /// auch fuer EF369, EF374, SA_erw
   0 "Entfaellt (Deutsche ohne weitere Staatsangehoerigkeit)" ///
   4 "4/8/27: Daenemark(4); Finnland(8); Schweden(27)" ///
   9 "Frankreich" ///
  10 "Griechenland" ///
  13 "Italien" ///
  21 "1/18/21: Belgien(1); Luxemburg(18); Niederlande(21)" ///
  22 "Oesterreich" ///
  23 "Polen" ///
  24 "Portugal" ///
  25 "3/25: Bulgarien(3); Rumaenien(25)" ///
  31 "7/15/17/19/31/37: Estland(7); Lettland(15); Litauen(17); Malta(19); Slowenien(31); Zypern(37)" ///
  32 "Spanien" ///
  33 "30/33: Slowakei(30); Tschechische Republik(33)" ///
  35 "Ungarn" ///
  36 "11/36: Irland(11); Vereinigtes Koenigreich(36)" ///
   2 "Bosnien und Herzegowina" ///
   5 "Ehemalige Sowjetunion" ///
   6 "Ehemaliges Jugoslawien" ///
  14 "Kroatien" ///
  26 "Russische Foederation" ///
  28 "12/16/20/28: Island(12); Liechtenstein(16); Norwegen(20); Schweiz(28)" ///
  34 "Tuerkei" ///
  38 "Sonstiges Osteuropa" ///
  39 "Sonstiges Europa" ///
  56 "Ukraine" ///
  58 "58/59: Serbien(58); Montenegro(59)" ///
  40 "Marokko" ///
  41 "Sonstiges Nordafrika" ///
  42 "Sonstiges Afrika (ohne Marokko)" ///
  43 "Vereinigte Staaten von Amerika (USA)" ///
  45 "44/45: Sonstiges Nordamerika [Kanada](44); Mittelamerika und Karibik(45)" ///
  46 "Suedamerika" ///
  47 "Irak" ///
  48 "Iran" ///
  49 "Sonstiger Naher und Mittlerer Osten (ohne Iran)" ///
  57 "Kasachstan" ///
  50 "Vietnam" ///
  51 "Afghanistan" ///
  52 "Sonstiges Sued- und Suedostasien" ///
  53 "China" ///
  54 "Sonstiges Ostasien" ///
  55 "55/98: Uebrige Welt(55); Staatenlos(98)" ///
  99 "Ohne Angabe bzw. unzutreffend"
label val migs migs
numlabel migs, add mask("[#] ") force

/* Zusammenfassungen MIGS
Europa: 
- EU-27:             4  9 10 13 21 22 23 24 25 31 32 33 35 36
- Sonstiges Europa:  2  5  6 14 26 28 34 38 39 56 58  
Afrika:  40 41 42  
Amerika: 43 45 46  
Asien, Australien und Ozeanien 
- Naher und Mittlerer Osten: 47 48 49 57 
- Sued- und Suedostasien: 50 51 52 
- China, Sonstiges Ostasien: 53 54 
Uebrige Welt, Staatenlos: 55 
*/


* ======= ENDE MIG-TYPISIERUNG ===== 


* Fallzahlen
tab1 mig migs, miss

* Bevoelkerung am Hauptwohnsitz, Hochrechnung: Jahresdurchschnitt (in 1.000)
table mig  if ef30<3 [iw=ef952], row format (%6.0f)
table migs if ef30<3 [iw=ef952], row format (%6.0f)


* Vergleich mit Tabelle 2, Fachserie 1 Bevoelkerung und Erwerbstaetigkeit, 
* Reihe 2.2, Bevoelkerung mit Migrationshintergrund. 
* Z_* := Zeilennummer in Tab. 2  Fachserie 1, Reihe 2.2, 
recode mig (0/77=1) (*=.), gen(Z001)
recode mig (0 11 77=1) (*=.), gen(Z002)
recode mig (21/29 31 32 41/43 52/54 62/64=1) (*=.), gen(Z005)
recode mig (21/29 31 41=1) (*=.), gen(Z034)
recode mig (41=1) (*=.), gen(Z062)
recode mig (21/29 31=1) (*=.), gen(Z089)
recode mig (21/29=1) (*=.), gen(Z090)
recode mig (31=1) (*=.), gen(Z097)
recode mig (42 43 32 52/54 62/64=1) (*=.), gen(Z119)
recode mig (42 43=1) (*=.), gen(Z126)
recode mig (32 52/54 62/64=1) (*=.), gen(Z133)
recode mig (32=1) (*=.), gen(Z134)
recode mig (52/54 62/64=1) (*=.), gen(Z140)
recode mig (62/64=1) (*=.), gen(Z141)
recode mig (52/54=1) (*=.), gen(Z142)
label var Z001 "001 Insgesamt [0-77]"
label var Z002 "002 Person ohne Migrationshintergrund [0,11,77]"
label var Z005 "005 Person mit Mig-hintergrund i.e.S. [21-64]"
label var Z034 "034 Bevoelkerung mit eigener Migrationserfahrung [21-31,41]"
label var Z062 "062 + Auslaender mit Mig-erfahrung [41]"
label var Z089 "089 + Deutsche mit Mig-erfahrung [21-31]"
label var Z090 "090 - Spaetaussiedler ohne Einbuergerung [21-29]"
label var Z097 "097 - Deutsche durch Einbuergerung [31]"
label var Z119 "119 Bevoelkerung ohne eigene Mig-erfahrung [32,42-64]"
label var Z126 "126 + Auslaender ohne Mig-erfahrung "
label var Z133 "133 + Deutsche mit Mig-hintergrund ohne Mig-erfahrung"
label var Z134 "134 - Deutscher durch Einbuergerung"
label var Z140 "140 - Deutscher mit Mig-hintergrund ohne Mig-erfahrung"
label var Z141 "141 # mit beidseitigem Mig-hintergrund"
label var Z142 "142 # mit einseitigem Mig-hintergrund"
summ Z001-Z142 if ef30>=1 & ef30<=2 [iw=ef952], sep(0)
* for var Z001-Z142 : tabstat ef952 if ef30<3, by(X) statistics( sum ) columns(variables) format(%6.0f)


/* Staatsangehoerigkeit zum Migrationsstatus
Hinweis zur Auswertung von MIGS im Vergleich zur Veroeffentlichung mit 
Tab. 2: Bevoelkerung nach detailliertem Migrationsstatus, Altersgruppen und Geschlecht
Fachserie 1, Reihe 2.2 
Statistisches Bundesamt (2009): Bevoelkerung mit Migrationshintergrund, Ergebnisse des Mikrozensus 2007. Wiesbaden. 
   http://www.destatis.de/jetspeed/portal/cms/Sites/destatis/Internet/DE/Content/Publikationen/Fachveroeffentlichungen/Bevoelkerung/MigrationIntegration/Migrationshintergrund2010220077004,property=file.pdf 
Deutsche Zuwanderer ohne Einbuergerung sowie in Deutschland geborene 
  Deutsche mit ein-/beidseitigem Migrationshintergund MIGS => 0 (deutsch)  */
gen MIGS_R = migs
replace MIGS_R = 0 if (mig>=0 & mig<=29) | (mig>=61 & mig<=74)
recode MIGS_R (0/99=1) (*=.), gen(Z00)
recode MIGS_R (01/39 56 58 59=1) (*=.), gen(Z06)
recode MIGS_R (01 03 04 07 08 09 10 11 13 15 17 18 19 21 22 23 24 25 27 30 31 32 33 35 36 37=1) (*=.), gen(Z07)
recode MIGS_R (10=1) (*=.), gen(Z08)
recode MIGS_R (13=1) (*=.), gen(Z09)
recode MIGS_R (23=1) (*=.), gen(Z10)
recode MIGS_R (02 05 06 12 14 16 20 26 28 29 34 38 39 56 58 59=1) (*=.), gen(Z12)
recode MIGS_R (2=1) (*=.), gen(Z13)
recode MIGS_R (14=1) (*=.), gen(Z14)
recode MIGS_R (26=1) (*=.), gen(Z15)
recode MIGS_R (34=1) (*=.), gen(Z17)
recode MIGS_R (56=1) (*=.), gen(Z18)
recode MIGS_R (40/42=1) (*=.), gen(Z19)
recode MIGS_R (43/46=1) (*=.), gen(Z20)
recode MIGS_R (47/55 57=1) (*=.), gen(Z22)
recode MIGS_R (47/49 57=1) (*=.), gen(Z23)
recode MIGS_R (57=1) (*=.), gen( Z24)
recode MIGS_R (50/52=1) (*=.), gen(Z25)
recode MIGS_R (98 99 0=1) (*=.), gen(Z26)
label var Z00 "Insgesamt [0-99]"
label var Z06 "Europa [01-39,56,58,59]"
label var Z07 "o EU 27 [01,03,04,07-11,13,15,17-19,21-25,27,30-33,35-37]"
label var Z08 "o Griechenland [10]"
label var Z09 "o Italien [13]"
label var Z10 "o Polen [23]"
label var Z12 "o Sonstiges Europa [02,05,06,12,14,16,20,26,28,29,34,38,39,56,58,59]"
label var Z13 "o Bosnien und Herzegowina [2]"
label var Z14 "o Kroatien [14]"
label var Z15 "o Russische Fderation [26]"
label var Z17 "o Trkei [34]" 
label var Z18 "o Ukraine [56]"
label var Z19 "Afrika [40-42]"
label var Z20 "Amerika [43-46]"
label var Z22 "Asien, Australien und Ozeanien [47-55,57]"
label var Z23 "o Naher und Mittlerer Osten [47-49,57]"                                        
label var Z24 "Kasachstan [57]"
label var Z25 "o Sd- und Sdostasien [50-52]"                    
label var Z26 "Ohne Angabe bzw. unzutreffend [98,99,0]"
* Bevoelkerung am Hauptwohnsitz, Hochrechnung: Jahresdurchschnitt (in 1.000)
* Personen mit Migrationshintergrund im engeren Sinn (Z005)
summ Z00-Z26 if ef30>=1 & ef30<=2 & Z005==1 [iw=ef952], sep(0)


* Sortierung nach Ordnungsnummern (EF1, EF3, EF4 (=EF4R), EF5 (=EF5R))
* oder Satznummer in Ausgangsdaten (ID_Org) fuer Zusammenfuehren der
* erstellten Variablen MIG, MIGS, MIGS_R zum Scientific Use File
sort ID_Org /* Alternativ: ... ef1 ef3 ef4 ef5 */


* Zwischenspeicherung mit korrigierten IDs und ggf. Variablenauswahl
/* keep  ef1      /// Bundesland
	 ef3      /// Auswahlbezirk
	 ef4      /// Haushaltsnummer korrigiert
	 ef5      /// Personennummer korrigiert
   	 ef12     /// Berichtsquartal
	 ef30     /// Bevoelkerung Haupt-/Nebenwohnsitz
	 mig      /// Migrationstatus
	 migs     /// Staatsangehoerigkeit zu MIG
	 MIGS_R   /// Staatsangehoerigkeit MIGS recodiert
	 ef952    /// Hochrechnungsfaktor Jahresdurchschnitt EF952
	 ID_Org   //  Satznummer Satznummer Ausgangsfile mz2007.dta
*/
save mig2007.dta, replace

* ################################################################################
* PROGRAMMENDE 
exit




